Changelog
=========

All notable changes to package_name will be documented here.

The format is based on `Keep a Changelog`_, and this project adheres to `Semantic Versioning`_.

.. _Keep a Changelog: https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: https://semver.org/spec/v2.0.0.html

Categories for changes are: Added, Changed, Deprecated, Removed, Fixed, Security.


Version `0.1.0 <https://github.com/your_organisation/package_name/tree/0.1.0>`__
--------------------------------------------------------------------------------

Release date: YYYY-MM-DD.
Initial release (to be released).
